==> ayatana-indicator-datetime_0.8.2.orig.tar.gz: ayatana-indicator-datetime-0.8.2/src/planner-upcoming.cpp <==
/*
 * Copyright 2014 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 3, as published
 * by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranties of
 * MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *   Charles Kerr <charles.kerr@canonical.com>
 */

#include <datetime/planner-upcoming.h>

namespace ayatana {
namespace indicator {
namespace datetime {

/***
****
***/

UpcomingPlanner::UpcomingPlanner(const std::shared_ptr<RangePlanner>& range_planner,
                                 const DateTime& date_in):
    m_range_planner(range_planner)
{
    date().changed().connect([this](const DateTime& dt){
        // set the range to the upcoming month
        const auto b = dt.add_days(-1).start_of_day();
        const auto e = b.add_full(0, 1, 0, 0, 0, 0);
        g_debug("%p setting date range to [%s..%s]", this, b.format("%F %T").c_str(), e.format("%F %T").c_str());
        m_range_planner->range().set(std::pair<DateTime,DateTime>(b,e));
    });

    date().set(date_in);
}

core::Property<DateTime>& UpcomingPlanner::date()
{
    return m_date;
}

core::Property<std::vector<Appointment>>& UpcomingPlanner::appointments()
{
    return m_range_planner->appointments();
}

/***
****
***/

} // namespace datetime
} // namespace indicator
} // namespace ayatana

==> ayatana-indicator-datetime_22.9.1.orig.tar.gz: ayatana-indicator-datetime-22.9.1/src/planner-upcoming.cpp <==
/*
 * Copyright 2014 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 3, as published
 * by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranties of
 * MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *   Charles Kerr <charles.kerr@canonical.com>
 */

#include <datetime/planner-upcoming.h>

namespace ayatana {
namespace indicator {
namespace datetime {

/***
****
***/

UpcomingPlanner::UpcomingPlanner(const std::shared_ptr<RangePlanner>& range_planner,
                                 const DateTime& date_in):
    m_range_planner(range_planner)
{
    date().changed().connect([this](const DateTime& dt){
        // set the range to the upcoming month
        const auto b = dt.start_of_day();
        const auto e = b.add_full(0, 1, 0, 0, 0, 0);
        g_debug("%p setting date range to [%s..%s]", this, b.format("%F %T").c_str(), e.format("%F %T").c_str());
        m_range_planner->range().set(std::pair<DateTime,DateTime>(b,e));
    });

    date().set(date_in);
}

core::Property<DateTime>& UpcomingPlanner::date()
{
    return m_date;
}

core::Property<std::vector<Appointment>>& UpcomingPlanner::appointments()
{
    return m_range_planner->appointments();
}

/***
****
***/

} // namespace datetime
} // namespace indicator
} // namespace ayatana
